# CHANGELOG

<!-- version list -->

## v0.1.1 (2025-11-19)

### Bug Fixes

- **build**: Fix readme and trigger release
  ([`4f622f5`](https://github.com/ademuk/cline-core/commit/4f622f58f16812bfef33536fd60d3c20e19910f9))

### Chores

- **build**: Include proto in build
  ([`1723b6c`](https://github.com/ademuk/cline-core/commit/1723b6c595dff6c0c09d8c89b2d3c0b0899ae82b))

- **docs**: Fix readme install and example
  ([`c8b138d`](https://github.com/ademuk/cline-core/commit/c8b138df4c1dfc5d6e561a6facf0dc02b7a706ba))


## v0.1.0 (2025-11-19)

- Initial Release
